@@ -198,37 +198,6 @@ class Speakers:
                 if device:
                     sonos_devices.append(device)
 
-    def print(self):
-        if not self._speakers:
-            return
-        households = {}
-        for device in self._speakers:
-            if device.household_id not in households:
-                households[device.household_id] = []
-            if device.is_visible:
-                visible = "Visible"
-            else:
-                visible = "Hidden"
-            households[device.household_id].append(
-                (
-                    device.speaker_name,
-                    device.ip_address,
-                    device.model_name.replace("Sonos ", ""),
-                    visible,
-                )
-            )
-
-        print()
-        if self._networks:
-            print("Networks searched: {}".format(self._networks))
-            print()
-        print("{} Sonos Household(s) found: ".format(len(households)))
-        for household in households:
-            print("  {}".format(household))
-        print()
-        pp = pprint.PrettyPrinter(width=100)
-        pp.pprint(households)
-
     def discover(self):
         """Discover the Sonos speakers on the network(s) to which
         this host is attached."""
@@ -263,9 +232,11 @@ class Speakers:
 
     def find(self, speaker_name, require_visible=True):
         """Find a speaker by name and return its SoCo object."""
+        # Normalise apostrophes
+        speaker_name = speaker_name.replace("’", "'")
         # Check for exact match first
         for speaker in self._speakers:
-            # Replace funny Sonos apostrophes
+            # Normalise apostrophes
             s = speaker.speaker_name.replace("’", "'")
             if speaker_name.lower() == s.lower():
                 if require_visible:
@@ -275,7 +246,7 @@ class Speakers:
                     return soco.SoCo(speaker.ip_address)
         # Check for partial match if no exact match
         for speaker in self._speakers:
-            # Replace funny Sonos apostrophes
+            # Normalise apostrophes
             s = speaker.speaker_name.replace("’", "'")
             if speaker_name.lower() in s.lower():
                 if require_visible:
@@ -284,3 +255,38 @@ class Speakers:
                 else:
                     return soco.SoCo(speaker.ip_address)
         return None
+
+    def print(self):
+        if not self._speakers:
+            return
+        households = {}
+        num_devices = 0
+        for device in self._speakers:
+            if device.household_id not in households:
+                households[device.household_id] = []
+            if device.is_visible:
+                visible = "Visible"
+            else:
+                visible = "Hidden"
+            households[device.household_id].append(
+                (
+                    device.speaker_name,
+                    device.ip_address,
+                    device.model_name.replace("Sonos ", ""),
+                    visible,
+                )
+            )
+            num_devices += 1
+
+        print()
+        if self._networks:
+            print("Networks searched: {}".format(self._networks))
+            print()
+        print("{} Sonos Household(s) found: ".format(len(households)))
+        for household in households:
+            print("  {}".format(household))
+        print()
+        print("{} Sonos devices found".format(num_devices))
+        print()
+        pp = pprint.PrettyPrinter(width=100)
+        pp.pprint(households)
